@@ -2,15 +2,16 @@ use 5.008;
 use strict;
 use warnings;
 
-package Dist::Zilla::Plugin::InstallGuide; # git description: v1.200010-1-g506c085
+package Dist::Zilla::Plugin::InstallGuide; # git description: v1.200013-7-g803cf68
 # ABSTRACT: Build an INSTALL file
 
-our $VERSION = '1.200011';
+our $VERSION = '1.200014';
 
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 with 'Dist::Zilla::Role::TextTemplate';
 with 'Dist::Zilla::Role::FileMunger';
+with 'Dist::Zilla::Role::ModuleMetadata';
 use List::Util 1.33 qw(first any);
 use namespace::autoclean;
 
@@ -64,6 +65,12 @@ Alternatively, if your CPAN shell is set up, you should just be able to do:
 
 ## Manual installation
 
+As a last resort, you can manually install it. If you have not already
+downloaded the release tarball, you can find the download link on the module's
+MetaCPAN page: https://metacpan.org/pod/{{ $package }}
+
+Untar the tarball, install configure prerequisites (see below), then build it:
+
 {{ $manual_installation }}
 The prerequisites of this distribution will also have to be installed manually. The
 prerequisites are listed in one of the files: `MYMETA.yml` or `MYMETA.json` generated
@@ -78,6 +85,23 @@ distribution's installer can be run.  They can be found under the
     $has_meta_json ? '"{prereqs}{configure}{requires}" key of META.json' : '',
 )}}.
 
+## Other Prerequisites
+
+This distribution may require additional modules to be installed after running
+{{ join(' or ', grep $installer{$_}, qw(Build.PL Makefile.PL)) }}.
+Look for prerequisites in the following phases:
+
+* to run {{ join(' or ',
+    ($installer{'Build.PL'} ? './Build' : ()),
+    ($installer{'Makefile.PL'} ? 'make' : ())) }}, PHASE = build
+* to use the module code itself, PHASE = runtime
+* to run tests, PHASE = test
+
+They can all be found in the {{ join(" or the\n",
+    $has_meta_yml ? '"PHASE_requires" key of MYMETA.yml' : '',
+    $has_meta_json ? '"{prereqs}{PHASE}{requires}" key of MYMETA.json' : '',
+)}}.
+
 ## Documentation
 
 {{ $dist->name }} documentation is available as POD.
@@ -89,15 +113,9 @@ For more information on installing Perl modules via CPAN, please see:
 https://www.cpan.org/modules/INSTALL.html
 END_TEXT
 
-our $common_instructions = <<'END_TEXT';
-As a last resort, you can manually install it. Download the tarball, untar it,
-install configure prerequisites (see below), then build it:
-
-END_TEXT
-
 has makemaker_manual_installation => (
     is => 'ro', isa => 'Str',
-    default => $common_instructions . <<'END_TEXT',
+    default => <<'END_TEXT',
     % perl Makefile.PL
     % make && make test
 
@@ -115,7 +133,7 @@ END_TEXT
 
 has module_build_manual_installation => (
     is => 'ro', isa => 'Str',
-    default => $common_instructions . <<'END_TEXT',
+    default => <<'END_TEXT',
     % perl Build.PL
     % ./Build && ./Build test
 
@@ -149,7 +167,6 @@ sub gather_files {
     $self->add_file(Dist::Zilla::File::InMemory->new({
         name => 'INSTALL',
         content => $self->template,
-
     }));
 
     return;
@@ -169,10 +186,10 @@ sub munge_files {
     my $manual_installation = '';
 
     my %installer = (
-        map {
+        map +(
             $_->isa('Dist::Zilla::Plugin::MakeMaker') ? ( 'Makefile.PL' => 1 ) : (),
             $_->does('Dist::Zilla::Role::BuildPL') ? ( 'Build.PL' => 1 ) : (),
-        } @{ $zilla->plugins }
+        ), @{ $zilla->plugins }
     );
 
     if ($installer{'Build.PL'}) {
@@ -185,7 +202,7 @@ sub munge_files {
         $self->log_fatal('neither Makefile.PL nor Build.PL is present, aborting');
     }
 
-    (my $main_package = $zilla->name) =~ s!-!::!g;
+    my $main_package = $self->module_metadata_for_file($zilla->main_module, collect_pod => 0)->name;
 
     my $file = first { $_->name eq 'INSTALL' } @{ $zilla->files };
 
@@ -196,6 +213,7 @@ sub munge_files {
             manual_installation => $manual_installation,
             has_meta_yml        => (any { $_->name eq 'META.yml' } @{ $zilla->files }),
             has_meta_json       => (any { $_->name eq 'META.json' } @{ $zilla->files }),
+            installer           => \%installer,
         }
     );
 
@@ -219,7 +237,7 @@ Dist::Zilla::Plugin::InstallGuide - Build an INSTALL file
 
 =head1 VERSION
 
-version 1.200011
+version 1.200014
 
 =for test_synopsis BEGIN { die "SKIP: synopsis isn't perl code" }
 
@@ -276,17 +294,17 @@ Mike Doherty <doherty@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Mike Doherty Karen Etheridge Marcel Gruenauer jonasbn Dan Book Dave Rolsky Apocalypse
+=for stopwords Karen Etheridge Mike Doherty Marcel Gruenauer jonasbn Dan Book Apocalypse Dave Rolsky
 
 =over 4
 
 =item *
 
-Mike Doherty <mike@mikedoherty.ca>
+Karen Etheridge <ether@cpan.org>
 
 =item *
 
-Karen Etheridge <ether@cpan.org>
+Mike Doherty <mike@mikedoherty.ca>
 
 =item *
 
@@ -306,11 +324,15 @@ Dan Book <grinnz@gmail.com>
 
 =item *
 
-Dave Rolsky <autarch@urth.org>
+Apocalypse <APOCAL@cpan.org>
 
 =item *
 
-Apocalypse <APOCAL@cpan.org>
+Dan Book <grinnz@grinnz.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
 
 =back
 
